@@ -415,7 +415,7 @@ private:
      * Zooms in by amount \p zoomFactor (which will zooming out if less than 1)
      * from clicking at \p mousePos (in widget coordinates).
      */
-    void zoomIn(const QPoint &mousePos, double zoomFactor);
+    void zoomIn(const QPointF &mousePos, double zoomFactor);
     /**
      * Zooms in from having drawn \p zoomRect (which is in widget coordinates).
      */
@@ -615,12 +615,12 @@ private:
      * This matrix transforms from real coordinates to painter coordinates.
      * (Note that the painter does not have any transformation applied).
      */
-    QMatrix m_realToPixel;
+    QTransform m_realToPixel;
     /**
      * The inverse matrix of m_realToPixel; it maps from pixel coordinates
      * to real X-Y coordinates.
      */
-    QMatrix m_pixelToReal;
+    QTransform m_pixelToReal;
 
     QString m_statusBarText[4];
 
